@@ -41,6 +41,8 @@
 #include <libgit2-glib/ggit-tree-builder.h>
 #include <libgit2-glib/ggit-remote.h>
 #include <libgit2-glib/ggit-rebase.h>
+#include <libgit2-glib/ggit-blob.h>
+#include <libgit2-glib/ggit-tag.h>
 
 G_BEGIN_DECLS
 
@@ -240,6 +242,22 @@ GgitBranch         *ggit_repository_lookup_branch     (GgitRepository        *re
                                                        GgitBranchType         branch_type,
                                                        GError               **error);
 
+GgitBlob           *ggit_repository_lookup_blob       (GgitRepository        *repository,
+                                                       GgitOId               *oid,
+                                                             GError         **error);
+
+GgitCommit         *ggit_repository_lookup_commit     (GgitRepository        *repository,
+                                                       GgitOId               *oid,
+                                                       GError               **error);
+
+GgitTag            *ggit_repository_lookup_tag        (GgitRepository        *repository,
+                                                       GgitOId               *oid,
+                                                       GError               **error);
+
+GgitTree           *ggit_repository_lookup_tree       (GgitRepository        *repository,
+                                                       GgitOId               *oid,
+                                                       GError               **error);
+
 GgitRemote         *ggit_repository_lookup_remote     (GgitRepository        *repository,
                                                        const gchar           *name,
                                                        GError               **error);
@@ -272,6 +290,11 @@ gboolean            ggit_repository_set_head          (GgitRepository        *re
 GFile              *ggit_repository_discover          (GFile                 *location,
                                                        GError               **error);
 
+GFile              *ggit_repository_discover_full     (GFile        *location,
+                                                       gboolean      across_fs,
+                                                       const gchar **ceiling_dirs,
+                                                       GError      **error);
+
 gboolean            ggit_repository_is_head_detached  (GgitRepository        *repository,
                                                        GError               **error);
 
